@@ -1,5 +1,5 @@
 package WebService::PayPal::PaymentsAdvanced::Response;
-$WebService::PayPal::PaymentsAdvanced::Response::VERSION = '0.000003';
+$WebService::PayPal::PaymentsAdvanced::Response::VERSION = '0.000004';
 use Moo;
 
 use Types::Standard qw( HashRef Str );
@@ -36,7 +36,7 @@ sub BUILD {
 
     return if defined $result && !$result;
 
-    if ( $result == 1 ) {
+    if ( $result && $result == 1 ) {
         WebService::PayPal::PaymentsAdvanced::Error::Authentication->throw(
             message => 'Authentication error: ' . $self->message,
             params  => $self->params,
@@ -76,7 +76,7 @@ WebService::PayPal::PaymentsAdvanced::Response - Generic response object
 
 =head1 VERSION
 
-version 0.000003
+version 0.000004
 
 =head1 SYNOPSIS
 
